{% if filetype_loop == 0 %}Name,ID,Display Name,Gateway,In Deployment,FQDN,Other PAP FQDN,Primary,SXP,IP Address,PAP Node,Primary PAP Node,pxGrid Node
{%- for node in node %}
{%-     for ip in node.Node.ipAddresses %}
{{ node.Node.name }},{{ node.Node.id }},{{ node.Node.displayName }},{{ node.Node.gateWay }},{{ node.Node.inDeployment }},{{ node.Node.fqdn }},{{ node.Node.otherPapFqdn }},{{ node.Node.ipAddress }},{{ node.Node.sxpIpAddress }},{{ ip }},{{ node.Node.papNode }},{{ node.Node.primaryPapNode }},{{ node.Node.pxGridNode }}
{%- endfor %}{%- endfor %}
{% else %}{% if filetype_loop == 1 %}
# ISE Nodes
| Name | ID | Display Name | Gateway | In Deployment | FQDN | Other PAP FQDN | Primary | SXP | IP Address | PAP Node | Primary PAP Node | pxGrid Node |
| ---- | -- | ------------ | ------- | ------------- | ---- | -------------- | ------- | --- | ---------- | -------- | ---------------- | ----------- |
{%- for node in node %}
{%-     for ip in node.Node.ipAddresses %}
| {{ node.Node.name }} | {{ node.Node.id }} | {{ node.Node.displayName }} | {{ node.Node.gateWay }} | {{ node.Node.inDeployment }} | {{ node.Node.fqdn }} | {{ node.Node.otherPapFqdn }} | {{ node.Node.ipAddress }} | {{ node.Node.sxpIpAddress }} | {{ ip }} | {{ node.Node.papNode }} | {{ node.Node.primaryPapNode }} | {{ node.Node.pxGridNode }} |
{%- endfor %}{%- endfor %}
{% else %}{% if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>ISE Nodes </h1>
<table id = "ise">
  <tr>
    <th>Name</th>
    <th>ID</th>
    <th>Display Name</th>
    <th>Gateway</th>
    <th>In Deployment</th>
    <th>FQDN</th>
    <th>Other PAP FQDN</th>
    <th>Primary</th>
    <th>SXP</th>
    <th>IP Address</th>
    <th>PAP Node</th>
    <th>Primary PAP Node</th>
    <th>pxGrid Node</th>
  </tr>
{%- for node in node %}
{%-     for ip in node.Node.ipAddresses %}  
  <tr>
    <td>{{ node.Node.name }}</td>
    <td>{{ node.Node.id }}</td>
    <td>{{ node.Node.displayName }}</td>
    <td>{{ node.Node.gateWay }}</td>
    <td>{{ node.Node.inDeployment }}</td>
    <td>{{ node.Node.fqdn }}</td>
    <td>{{ node.Node.otherPapFqdn }}</td>
    <td>{{ node.Node.ipAddress }}</td>
    <td>{{ node.Node.sxpIpAddress }}</td>
    <td>{{ ip }}</td>
    <td>{{ node.Node.papNode }}</td>
    <td>{{ node.Node.primaryPapNode }}</td>
    <td>{{ node.Node.pxGridNode }}</td>
  </tr>
{%- endfor %}{%- endfor %}  
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#ise thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#ise thead');

    var table = $('#ise').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>
{%- else %}
# ISE Nodes
{%- for node in node %}
## {{ node.Node.name }}
### ID: {{ node.Node.id }}
### Display Name: {{ node.Node.displayName }}
### Gateway: {{ node.Node.gateWay }}
### In Deployment: {{ node.Node.inDeployment }}
### FQDN: {{ node.Node.fqdn }}
#### Other PAP FQDN: {{ node.Node.otherPapFqdn }}
### IP Addresses
#### Primary: {{ node.Node.ipAddress }}
#### SXP: {{ node.Node.sxpIpAddress }}
{%-     for ip in node.Node.ipAddresses %}
#### {{ ip }}
{%-     endfor %}
### Node Type
#### PAP Node: {{ node.Node.papNode }}
##### Primary PAP Node: {{ node.Node.primaryPapNode }}
#### pxGrid Node: {{ node.Node.pxGridNode }}
{%- endfor %}
{%- endif %}{% endif %}{% endif %}